@@ -17,6 +17,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include <wx/intl.h>
 #include <iostream>
 #include <cstdio>
 #include <stdexcept>
@@ -28,10 +29,6 @@
 #include "contexthandler.h"
 #include "getword.h"
 
-#ifdef __WXMSW__
-       #include "aspellpaths.h"
-#endif
-
 WrapAspell::WrapAspell (
                        std::string lang
 #if !defined(USE_ENCHANT) && defined(__WXMSW__)
