@@ -18,7 +18,6 @@
  */
 
 #include "wrapxerces.h"
-#define XERCES_TMPLSINC
 
 #include <xercesc/sax2/XMLReaderFactory.hpp>
 #include <xercesc/sax2/SAX2XMLReader.hpp>
@@ -31,24 +30,33 @@
 
 using namespace xercesc;
 
-WrapXerces::WrapXerces( std::string catalogPath, std::string catalogUtilityPath )
+void WrapXerces::Init() throw()
 {
-	try
+	static class Initializer
 	{
-		XMLPlatformUtils::Initialize();
-	}
-	catch ( XMLException& e )
-	{
-		throw std::runtime_error ( "Cannot initialize Xerces" );
-	}
+	public:
+		Initializer()
+		{
+			XMLPlatformUtils::Initialize();
+		}
+		~Initializer()
+		{
+			XMLPlatformUtils::Terminate();
+		}
+	} dummy;
+}
+
+WrapXerces::WrapXerces()
+{
+	WrapXerces::Init();
+
 	errorPosition = std::make_pair ( 1, 1 );
-	catalogResolver = new XercesCatalogResolver( catalogPath, catalogUtilityPath );
+	catalogResolver = new XercesCatalogResolver();
 }
 
 WrapXerces::~WrapXerces()
 {
 	delete catalogResolver;
-	XMLPlatformUtils::Terminate();	
 }
 
 bool WrapXerces::validate ( const std::string& fileName )
@@ -80,26 +88,22 @@ bool WrapXerces::validate ( const std::string& fileName )
 	catch ( XMLException& e )
 	{
 		delete parser;
-		char *err = XMLString::transcode ( e.getMessage() );
-		lastError = err;
-		XMLString::release ( &err );
+		lastError = toString ( e.getMessage() );
 		return false;
 	}
 	catch ( SAXParseException& e )
 	{
 		delete parser;
-		char *err = XMLString::transcode ( e.getMessage() );
-		std::stringstream ss;
-		ss << "Validation stopped at line " << e.getLineNumber() << ", column " << e.getColumnNumber() << ": " << err;
-		lastError = ss.str();
+		lastError << _T ( "Validation stopped at line " )
+		    << e.getLineNumber() << _T ( ", column " ) << e.getColumnNumber()
+		    << _T ( ": " ) << toString ( e.getMessage() );
 		errorPosition = std::make_pair ( e.getLineNumber(), e.getColumnNumber() );
-		XMLString::release ( &err );
 		return false;
 	}
 	catch ( ... )
 	{
 		delete parser;
-		lastError = "Unexpected validation error";
+		lastError = _T ( "Unexpected validation error" );
 		return false;
 	}
 	delete parser;
@@ -109,10 +113,11 @@ bool WrapXerces::validate ( const std::string& fileName )
 // tbd: cache grammar
 bool WrapXerces::validateMemory (
 	const char *buffer,
+	size_t len,
 	const char *system,
-	unsigned len )
+	wxThread *thread /*= NULL*/ )
 {
-	SAX2XMLReader *parser = XMLReaderFactory::createXMLReader();
+	std::auto_ptr<SAX2XMLReader> parser ( XMLReaderFactory::createXMLReader() );
 
 	parser->setFeature ( XMLUni::fgSAX2CoreNameSpaces, true );
 	parser->setFeature ( XMLUni::fgSAX2CoreValidation, true );
@@ -121,7 +126,7 @@ bool WrapXerces::validateMemory (
 	//parser->setFeature ( XMLUni::fgXercesSchemaFullChecking, true );
 	parser->setFeature ( XMLUni::fgXercesValidationErrorAsFatal, true );
 	parser->setFeature ( XMLUni::fgXercesLoadExternalDTD, true );
-	
+
 	DefaultHandler handler;
 	MySAX2Handler mySAX2Handler;
 	parser->setContentHandler ( &handler );
@@ -130,50 +135,50 @@ bool WrapXerces::validateMemory (
 	parser->setEntityResolver ( catalogResolver );
 
 	XMLByte* xmlBuffer = (XMLByte*) buffer;
-        MemBufInputSource source (
-		xmlBuffer,
-                len,
-		system );
-  
+	MemBufInputSource source ( xmlBuffer, len, system );
+
 	try
 	{
-		parser->parse ( source );
+		if ( thread == NULL )
+		{
+			parser->parse ( source );
+		}
+		else if ( !thread->TestDestroy() )
+		{
+			XMLPScanToken token;
+			if ( parser->parseFirst ( source, token ) )
+				while ( (!thread->TestDestroy()) && parser->parseNext ( token ) )
+					continue;
+		}
 	}
 	catch ( XMLException& e )
 	{
-		delete parser;
-		lastError = "";
+		lastError = wxEmptyString;
 		return false;
 	}
 	catch ( SAXParseException& e )
 	{
-		delete parser;
-		char *err = XMLString::transcode ( e.getMessage() );
-		std::stringstream ss;
-		ss << "Ln " << e.getLineNumber() << " Col " << e.getColumnNumber() << ": " << err;
-		lastError = ss.str();
+		lastError << _T ( "Ln " ) << e.getLineNumber() << _T ( " Col " )
+		    << e.getColumnNumber() << _T ( ": " ) << toString ( e.getMessage() );
 		errorPosition = std::make_pair ( e.getLineNumber(), e.getColumnNumber() );
-		XMLString::release ( &err );
 		return false;
 	}
 	catch ( ... )
 	{
-		delete parser;
-		lastError = "";
+		if ( thread != NULL && thread->TestDestroy() )
+			throw;
+		lastError = wxEmptyString;
 		return false;
 	}
-	delete parser;
 	return true;
 }
 
-std::string WrapXerces::getLastError()
+const wxString &WrapXerces::getLastError()
 {
-	char *rawError, *it;
-	rawError = (char *)lastError.c_str();
-	it = strstr ( rawError, "Message:" );
-	if ( it )
+	int i = lastError.Find( _T ( "Message:" ) );
+	if ( i != wxNOT_FOUND )
 	{
-		lastError = it + 8;
+		lastError = lastError.substr( i );
 	}
 
 	return lastError;
@@ -183,3 +188,10 @@ std::pair<int, int> WrapXerces::getErrorPosition()
 {
 	return errorPosition;
 }
+
+wxString WrapXerces::toString ( const XMLCh *str )
+{
+	static wxMBConvUTF16 conv;
+
+	return wxString ( ( const char * ) str, conv );
+}
