@@ -27,7 +27,8 @@
 #include <string>
 #include <set>
 #include <map>
-#include "validationthread.h"
+
+class ValidationThread;
 
 struct XmlCtrlProperties
 {
@@ -94,15 +95,13 @@ class XmlCtrl: public wxStyledTextCtrl
 	public:
 		XmlCtrl (
 		    wxWindow *parent,
-		    XmlCtrlProperties propertiesParameter,
+		    const XmlCtrlProperties &propertiesParameter,
 		    bool *protectTagsParameter,
 		    int visibilityStateParameter = SHOW_TAGS,
 		    int typeParameter = FILE_TYPE_XML,
 		    wxWindowID id = wxID_ANY,
 		    const char *buffer = NULL,
 		    size_t bufferLen = 0,
-		    const std::string& catalogPath = "",
-		    const std::string& catalogUtilityPath = "",
 		    const std::string& basePath = "",
 		    const std::string& auxPath = "",
 		    const wxPoint &position = wxDefaultPosition,
@@ -112,7 +111,7 @@ class XmlCtrl: public wxStyledTextCtrl
 		int getType();
 		int getParentCloseAngleBracket ( int pos, int range = USHRT_MAX * 4 );
 		void applyProperties (
-		    XmlCtrlProperties propertiesParameter,
+		    const XmlCtrlProperties &propertiesParameter,
 		    bool zoomOnly = false );
 		void applyVisibilityState ( int state = SHOW_TAGS );
 		void updatePromptMaps();
@@ -130,10 +129,10 @@ class XmlCtrl: public wxStyledTextCtrl
 		void clearErrorIndicators ( int maxLine = 0 );
 		wxString getParent();
 		wxString getLastElementName ( int pos );
-		std::set<wxString> getChildren ( const wxString& parent );
-		std::set<std::string> getEntitySet();
-		std::set<std::string> getAttributes ( const wxString& parent );
-		std::string getElementStructure ( const wxString& parent );
+		const std::set<wxString> &getChildren ( const wxString& parent );
+		const std::set<wxString> &getEntitySet();
+		const std::set<std::string> &getAttributes ( const wxString& parent );
+		wxString getElementStructure ( const wxString& parent );
 		bool canInsertAt ( int pos );
 		int getTagStartPos ( int pos );
 		void toggleLineBackground();
@@ -146,15 +145,8 @@ class XmlCtrl: public wxStyledTextCtrl
 		bool getValidationRequired();
 		void setValidationRequired ( bool b );
 	private:
-		// the following are used for background validation
-		ValidationThread *validationThread;
-		bool validationStarted,
-			validationFinished,
-			validationSuccess;
-		bool *validationReleasePtr;
-		std::pair<int, int> validationPosition;
-		std::string validationMessage;
-	
+		ValidationThread *validationThread; // used for background validation
+
 		int type;
 		bool *protectTags;
 		bool validationRequired, grammarFound;
@@ -163,13 +155,13 @@ class XmlCtrl: public wxStyledTextCtrl
 		int currentMaxLine;
 		int lineBackgroundState;
 		wxColour baseBackground, alternateBackground;
-		std::map<std::string, std::map<std::string, std::set<std::string> > >
+		std::map<wxString, std::map<wxString, std::set<wxString> > >
 		attributeMap;
-		std::map<std::string, std::set<std::string> > requiredAttributeMap;
-		std::map<std::string, std::set<std::string> > elementMap;
-		std::set<std::string> entitySet;
-		std::map<std::string, std::string> elementStructureMap;
-		std::string catalogPath, catalogUtilityPath, basePath, auxPath;
+		std::map<wxString, std::set<wxString> > requiredAttributeMap;
+		std::map<wxString, std::set<wxString> > elementMap;
+		std::set<wxString> entitySet;
+		std::map<wxString, wxString> elementStructureMap;
+		std::string basePath, auxPath;
 		XmlCtrlProperties properties;
 		wxString getLastAttributeName ( int pos );
 		int getAttributeStartPos ( int pos );
@@ -191,6 +183,7 @@ class XmlCtrl: public wxStyledTextCtrl
 		void OnMarginClick ( wxStyledTextEvent& event );
 		void OnChar ( wxKeyEvent& event );
 		void OnIdle ( wxIdleEvent& event );
+		void OnValidationCompleted (wxCommandEvent &event);
 		void OnKeyPressed ( wxKeyEvent& event );
 		void OnMouseLeftDown ( wxMouseEvent& event );
 		void OnMouseLeftUp ( wxMouseEvent& event );
